package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````X!\```````!``````````."C````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````*ZB`````````````````````````````#,````````````````````!
M``````````$````%````````````````````````````````````3(T`````
M``!,C0`````````0`````````0````8`````D`````````"0`````````)``
M``````"($@```````+`B`````````!`````````"````!@```!B0````````
M&)`````````8D````````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0````(C0````````B-````````"(T````````4````````
M`!0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$`````)``````````
MD`````````"0`````````!``````````$`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`&%<X[,`K:BJ)*`SFNOT0V&>;<7$!````!`````!````1TY5```````$````
M#P`````````1````2`````0````(````()`0`05`!,0H`@$$@(8$A(()```)
M(`0(B(`00;H``H@`````2````$L```!.````3P```%8```!7````60```%L`
M``!<````70```%\```!A````8@```&0``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@
M:PE#UF:OS&89?@J'0D75[(D'<--S4)_8,V+;[3[/TFP5C"7,##J7"_]A\F%_
MJ9R;X*<""FL:GE"CX/M)``````````````````````````````````````,`
M#``P'@``````````````````W0(``!$`````````````````````````S0``
M`!(`````````````````````````=@$``!(`````````````````````````
MBP(``!(`````````````````````````=````!(`````````````````````
M````P@```!$`````````````````````````1@$``!(`````````````````
M````````1@(``!(`````````````````````````B@$``!(`````````````
M````````````70$``!(`````````````````````````IP(``!(`````````
M````````````````XP```!(`````````````````````````_`$``!(`````
M````````````````````PP(``!$`````````````````````````XP$``!(`
M````````````````````````I@$``!(`````````````````````````%`$`
M`!(`````````````````````````!`$``!(`````````````````````````
M]@```!(`````````````````````````.P(``!(`````````````````````
M````D0$``!(`````````````````````````)0(``!(`````````````````
M````````RP(``!(``````````````````````````0```"``````````````
M````````````LP$``!(`````````````````````````9`$``!(`````````
M````````````````'0```"``````````````````````````+0(``!(`````
M````````````````````V@$``!(`````````````````````````P@(``"$`
M````````````````````````-P```!(`````````````````````````A`(`
M`!(`````````````````````````P0(``!$`````````````````````````
MTP$``!(`````````````````````````-@$``!(`````````````````````
M````5`(``!(`````````````````````````5````!(`````````````````
M````````L0```!(`````````````````````````90```!(`````````````
M````````````6P(``!(`````````````````````````RP$``!(`````````
M````````````````E0```!(`````````````````````````T@```!(`````
M````````````````````JP$``!(`````````````````````````-`(``!(`
M````````````````````````A`$``!(`````````````````````````*`$`
M`!(`````````````````````````?0$``!(`````````````````````````
M30(``!(`````````````````````````#0(``!$`````````````````````
M````UP```!(`````````````````````````+`(``!(`````````````````
M````````O`$``"(`````````````````````````DP(``!(`````````````
M````````````@````!(`````````````````````````N0(``!(`````````
M````````````````00(``!(`````````````````````````80(``!(`````
M````````````````````40$``!(`````````````````````````:`(``!(`
M````````````````````````I0,``!(`````````````````````````I```
M`!$`````````````````````````F`$``!(`````````````````````````
M'0$``!(`````````````````````````10```!(`````````````````````
M````Z@$``!(`````````````````````````L0(``!(`````````````````
M````````%`(``!(`````````````````````````=@(``!(`````````````
M````````````;P$``!(`````````````````````````K@,``!(`#`"8-@``
M`````-8`````````0`0``!(`#``4+@```````+(&````````]P$``!(`#``P
M'@```````*X!````````)0,``!(`#`"()@````````(`````````0P,``!(`
M#`#&-````````-(!````````9@0``!(`#`"*)@```````-8!````````)@0`
M`!``%@"(H@``````````````````-@,``!(`#`!@*````````!X`````````
M60,``!(`#`#4+````````&0`````````Q@,``!$`#0"H3`````````0`````
M`````P0``!(`#`!`2@```````-@`````````'@0``!(`#`"8)0```````#(`
M````````.P0``!``%@"PL@``````````````````5`0``!(`#`!0+0``````
M`,0`````````U0,``!``%```H```````````````````?0,``!(`#`!^*```
M`````,(`````````\0,``!``\?^(J@``````````````````300``!``%0"(
MH@``````````````````<P0``!$`%`!`H`````````@`````````#@0``!``
M%0"(H@``````````````````VP,``!(`#`#@'P```````"(`````````X@,`
M`!``%```H```````````````````,@0``!(`#`#L20```````%0`````````
MUP,``"``%```H```````````````````N@,``!``%@"PL@``````````````
M````DP,``!(`#``X+0```````!@`````````9P,``!(`#`#*)0```````+X`
M````````B0,``!(`#``82P```````'X!````````?00``!(`#`!`*0``````
M`)0#`````````%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`&]P96XV-`!S=')T;VL`<W1R9'5P`&UK9&ER`'-T
M<FQE;@!S=')S='(`7U]S<')I;G1F7V-H:P!E>&ET`&UE;6UO=F4`<F5A9&QI
M;FL`7U]C>&%?9FEN86QI>F4`;'-E96LV-`!G971P:60`8VQO<V5D:7(`86-C
M97-S`%]?;&EB8U]S=&%R=%]M86EN`%]?97)R;F]?;&]C871I;VX`<W1D97)R
M`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&QS=&%T-C0`<W1R8VAR`')M9&ER
M`')E860`9V5T=6ED`&UE;6-H<@!S=')C;7``8VQO<V4`;65M<V5T`%]?9G!R
M:6YT9E]C:&L`7U]S=')N8W!Y7V-H:P!M96UC<'D`<W1R;F-M<`!P=&AR96%D
M7V=E='-P96-I9FEC`')E861D:7(V-`!O<&5N9&ER`')E86QL;V,`7U]E;G9I
M<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E
M<FPN<V\N-2XS-`!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T9"YS
M;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S960`
M7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT97(D
M`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?<W1A
M<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U
M<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV
M`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P!'3$E"0U\R+C(W`````````@`!``,`
M`P`!``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#``,``P`#``$``P`!
M``$`!``#``,``0`#``,``P`!``,``0`!``$``P`#``$``P`#``,``P`!``,`
M`P`#``$`!``#``4``0`#``,``P`!``,``P`!``,``0`!``4``P`#``,``P`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$````!``,`_P(``!````!`````M)&6!@``!0"*!```$```
M`+.1E@8```0`E00``!````"'D98&```#`*`$`````````0`!``D#```0````
M`````(>1E@8```(`H`0`````````D`````````,``````````B`````````(
MD`````````,`````````EB`````````0D`````````,`````````7"``````
M````H`````````,``````````*`````````0H`````````,`````````"$X`
M```````8H`````````,`````````4%`````````@H`````````,`````````
M6%`````````HH`````````,`````````8%`````````PH`````````,`````
M````:%````````!`H`````````,`````````<%````````"`H@````````,`
M````````,!X````````HH@````````(````"```````````````PH@``````
M``(````'```````````````XH@````````(````-``````````````!`H@``
M``````(````/``````````````!(H@````````(````9``````````````!0
MH@````````(````<``````````````!8H@````````(````D````````````
M``!@H@````````(````F``````````````!HH@````````(````S````````
M``````!PH@````````(````V``````````````!XH@````````(````_````
M``````````!8H`````````4````#``````````````!@H`````````4````$
M``````````````!HH`````````4````%``````````````!PH`````````4`
M```&``````````````!XH`````````4````(``````````````"`H```````
M``4````)``````````````"(H`````````4````*``````````````"0H```
M``````4````+``````````````"8H`````````4````,``````````````"@
MH`````````4````.``````````````"HH`````````4````0````````````
M``"PH`````````4````1``````````````"XH`````````4````2````````
M``````#`H`````````4````3``````````````#(H`````````4````4````
M``````````#0H`````````4````5``````````````#8H`````````4````6
M``````````````#@H`````````4````7``````````````#HH`````````4`
M```8``````````````#PH`````````4````:``````````````#XH```````
M``4````;````````````````H0````````4````=```````````````(H0``
M``````4````>```````````````0H0````````4````@```````````````8
MH0````````4````A```````````````@H0````````4````C````````````
M```HH0````````4````E```````````````PH0````````4````G````````
M```````XH0````````4````H``````````````!`H0````````4````I````
M``````````!(H0````````4````J``````````````!0H0````````4````K
M``````````````!8H0````````4````L``````````````!@H0````````4`
M```M``````````````!HH0````````4````N``````````````!PH0``````
M``4````O``````````````!XH0````````4````P``````````````"`H0``
M``````4````Q``````````````"(H0````````4````R``````````````"0
MH0````````4````T``````````````"8H0````````4````U````````````
M``"@H0````````4````W``````````````"HH0````````4````X````````
M``````"PH0````````4````Y``````````````"XH0````````4````Z````
M``````````#`H0````````4````[``````````````#(H0````````4````\
M``````````````#0H0````````4````]``````````````#8H0````````4`
M```^``````````````#@H0````````4```!```````````````#HH0``````
M``4```!!``````````````#PH0````````4```!"``````````````#XH0``
M``````4```!#````````````````H@````````4```!$```````````````(
MH@````````4```!%```````````````0H@````````4```!&````````````
M```8H@````````4```!'`````````````````````````)>#```S`\-!`[Z#
M7!,#0_V3@H-<$U,3`(.R@@!G``X`%XX```,^CEMG`PX`$P```!>.```#/@Y;
M9P,.`!,````7C@```SZ.6F<##@`3````%XX```,^#EIG`PX`$P```!>.```#
M/HY99P,.`!,````7C@```SX.66<##@`3````%XX```,^CEAG`PX`$P```!>.
M```#/@Y89P,.`!,````7C@```SZ.5V<##@`3````%XX```,^#E=G`PX`$P``
M`!>.```#/HY69P,.`!,````7C@```SX.5F<##@`3````%XX```,^CE5G`PX`
M$P```!>.```#/@Y59P,.`!,````7C@```SZ.5&<##@`3````%XX```,^#E1G
M`PX`$P```!>.```#/HY39P,.`!,````7C@```SX.4V<##@`3````%XX```,^
MCE)G`PX`$P```!>.```#/@Y29P,.`!,````7C@```SZ.46<##@`3````%XX`
M``,^#E%G`PX`$P```!>.```#/HY09P,.`!,````7C@```SX.4&<##@`3````
M%XX```,^CD]G`PX`$P```!>.```#/@Y/9P,.`!,````7C@```SZ.3F<##@`3
M````%XX```,^#DYG`PX`$P```!>.```#/HY-9P,.`!,````7C@```SX.36<#
M#@`3````%XX```,^CDQG`PX`$P```!>.```#/@Y,9P,.`!,````7C@```SZ.
M2V<##@`3````%XX```,^#DMG`PX`$P```!>.```#/HY*9P,.`!,````7C@``
M`SX.2F<##@`3````%XX```,^CDEG`PX`$P```!>.```#/@Y)9P,.`!,````7
MC@```SZ.2&<##@`3````%XX```,^#DAG`PX`$P```!>.```#/HY'9P,.`!,`
M```7C@```SX.1V<##@`3````%XX```,^CD9G`PX`$P```!>.```#/@Y&9P,.
M`!,````7C@```SZ.16<##@`3````%XX```,^#D5G`PX`$P```!>.```#/HY$
M9P,.`!,````7C@```SX.1&<##@`3````%XX```,^CD-G`PX`$P```!>.```#
M/@Y#9P,.`!,````7C@```SZ.0F<##@`3````%XX```,^#D)G`PX`$P```!>.
M```#/HY!9P,.`!,````7C@```SX.06<##@`3````%XX```,^CD!G`PX`$P``
M`!>.```#/@Y`9P,.`!,````7C@```SZ./V<##@`3````'7&JAZ;DEX0``(.T
M)#\NZ#+D#`@P`&@(/LZ<8#[T@4>&[*+HRN!._._PG_<7A@```S;&/;*%%X4`
M``,UI3_O()!BEX<``(.W9T"#QP<`8XX'#A>$```3!.1`%XD```,Y:3H#)0D`
M[_"_Z0-'I4JJAP,E"0`39R<`(X7G2N_P7^B#1Z5*<D:3YQ<`&P=&`",%]4H3
M%3<`&PDV`._P?^O"9?)'".288:J&&.$7-P``$P=G%ACE%X<```,WQQ48Z1<W
M```3!Z<5&.T%1V-;]PR;B#<`1HBA!1%'B&&3%S<`MI<%)XCCH07CF>C^FP<(
M``ALC@>VETJ&`4>7!0``DX7E8".P!P#O\-^Z*HD]Q0ALDPE!`N_P_]G.A1<U
M```3!07E[P"`%#G-"&SO\)^T[_!?RR)WG&"YCP%'K>OF8$9DIF3B>4J%!FDE
M88*`[_!_QA>$```3!"0Q".PQQ>_P?\T7B0```SDI*@,E"0#O\'_9A6<^E:,+
M!:3UM0AL[_!_NRJ)<;<(:`'%[Q`@;G&_SH47-0``$P4EUN\`(`T(Z$G5Y;>1
M1[&W!47O\+^W[_!_X@``[P`@`JJ'%X4```,UI2F"93``$W$!_X%&`4<*B._P
M7]X"D)>1``"3@6&H@H```!>%```3!:4#EX<``).')P-CB*<`EX<``(.W9R*1
MPX*'@H`7A0``$P6%`9>%``"3A04!B8V3US5`_9&^E86%F<67AP``@[<G()'#
M@H>"@$$1(N`7A```$P2$(H-'!``&Y(7CEX<``(.W!R"1QQ>%```#-67X@I?O
M\+_XA4<C`/0`HF`"9$$!@H!IOSEQ!OPB^";T2O!.[%+H5N1:X$G!EX<``(.W
M1QD#NP<`8PH+!H-'!0"JB2Z**HD3!]`#O<-CAN<`@T<9``4)_?L["3E!`S0+
M`!W`VH23"M`#(H5*ALZ%[_`_G;,')`$)Y8/'!P!C@%<#@&2A!'7PXG`BA4)T
MHG0">>)I0FJB:@)K(6&"@+.$9$&-A`4)(R":`$J4\;\!1.&_`4EMMQ5QRN$7
MB0```SD)#X;MHNFFY4[]4OE6]5KQ7NUBZ8,W"0`^Y8%'"<6#1P4`*H2%YRIG
M@S<)`+F/`4=CG`<,[F!.9*YD#FGJ>4IZJGH*>^IK2FPM88*`[_!_QJJ$<=D7
M.@``$PKJL9,)@0`]:Y%J)H7O\-^7/<F#1C4!DPLU`9N&)OV!YH/&&P#]T@-'
M-0$;!R?]/<,BA>_P?Y,JC%Z%[_#_DCL%K``))>_P7Y/>AR*'TH9]5H5%JHOO
M\%^\SH5>A>_PWY_]5V,(]0#B1[/W9P&!)V.,5P->A>_P7YI>A>_P_Z@FA>_P
MGY!9]2:%[_`?GB*%[_"_EBV_`\<;`!L')_U1^P/'*P`EUW&W7H7O\%_O\;?O
M\+^[<7$F[9>$``"#M*3]+`"<8#[E@4<B\0;U*H3O\-^K#>'B1[UF$6?UCV.%
MYP`I9V.:YP")12*%[_`?C!,U%0`1H`%%*F><8+F/`4>1YZIP"G3J9$UA@H#O
M\!^V77%6[/UWA6K]<N$7$X<*`:+@)OQ*^%+PAN1.]#Z7%I$NBK,%)P`3AXH`
M"I<%9!>)```#.6GU@S<)`!SC@4>JA!,&]/\7-0``$P4%G>_P'XZ;!P4`8UKP
M!!.'"@$*ES,$AT";B??_3I0#1X3_+>]CC0D"?72%9V$4P0>BES.$)P!.AI,%
M\`(BA>_P7YT1S9>'``"#M^?OB$/O\%^?SH8BAJ:%[_"_E"&HEX<``(.W1^Z(
M0^_POYU2AJ:%[_`_@H5GH0>*EYAC@S<)`+F/`4>1[X5B%I&F8`9DXG1">:)Y
M`GKB:F%A@H"^B6FW[_`_IQUQHNBFY,K@4OB&[$[\5O1:\%[L8NB#QP4`%XD`
M``,YR>>JA).'-_R3MQ<`,X3U`"*%@S<)`#[D@4?O\$_S*HI,`":%[_`_S&G-
MJHGO\"_R8WA%"Y)*%XL```,[B^6."@/'!`"FAY,&T`-C!@<28P;7``/'%P"%
M!WW[A9^#.0L`$P4J`#Z5UIGO\&_O(["I`#'%`S<+`(/'!``3A10`5I<48Q,&
MT`,C@/8`@>N-J(-'!0`%!:,`]P"]PS:'A0;CF,?^DP;0`Y,'%P`C`-<``T<$
M`(4'!02CC^?^=?LB9X,W"0"YCP%'S>_F8$9DIF0&:>)Y0GJB>@)[XFM";"5A
M@H"#1P0`A0D%!*./^?[AVX-'!`"%"04$HX_Y_OWSP;<VATVW%XL```,[R]@#
M/`L`@S<,`*7'XH>!29AGSH:A!X4I9?^-)I.5-@"7AP``DX=GVYA#!>L%1RZ%
MF,/O\$_BJHLUW9.:.0!6AN*%[_!/^R,P>P&;AQD`C@>^FR.P"P!.PL6U8H7O
M\+^#(S"K`*J+.=63FCD`^;^!1]6UP46!26VW[_#_C$$1(N`7A````S1DSPA`
M!N3O\*_^"$#O\$_^EV8``).&AG<7A@```S8&T)<E``"3A85V[_"?A0A`[_`O
M_`)DHF`7-P``$P<GK(%'NH87%@``$P9&])<E``"3A>5U00%O\,_K01$&Y)>'
M``"#MT?)B$/O\*_XHF"79@``DX;&<1>&```#-D;*ER4``).%Q7!!`6_PK_]=
M<4KX^7():8;DHN`F_$[T$P>)`1:1"I>7B0``@[EIQ(.W"0`<XX%'[_#OXWET
M(123!PD"HI<SA"<`!68JAY<G``"3AX=OER8``).&AF\%!H5%(H7O\"_Y_73!
M%),'"0*FE[.$)P`BA05FIH7O\*_9&P0%``%)8T\$`!L%%`#O\(_,*HD!R2*&
MIH5*E._PK]PC``0`B6?A!XJ7F&.#MPD`N8\!1YGKB6(6D:9@2H4&9.)T0GFB
M>6%A@H#O\,_WB;=1<=+AA69]>OUR$P=*]Y.'!@FB\:;MRNEB\8;USN56_5KY
M7O5F[;J7%I$3AX8("I<7C````SSLMBJ)+H07)0``$P6E9;.%)P"#-PP`'..!
M1^_P_YNJA),%\`)*A>_PK]TYP1<E```3!45DRH7O\-_)2H6%9Y.'APB*EYAC
M@S<,`+F/`4=CEP<4A6(6D:YP#G3N9$YIKFD.:NIZ2GNJ>PI\ZFQM88*`2H7O
M\.^\JHHBA>_P;]N7)0``DX4E8._PK[:!*BJ$6=V%9Y,)BO\3AP<)3I>S"2<`
M$X<'"9.'!PF*EP5KLXMG08-'!``3"HKW4I>7+```DXSL63,*)P#1SY'$HH4F
MA>_P+\L]R2*%[_"OMIL']?^S!O0``\8&`!,'\`(!)6,>Y@`3!O`"/H7]-R.`
M!@"S!O0``\<&`.,(Q_Z;AQH`J9_CWV?QA45*B)<G``"3AR=7(H>7)@``DX8&
M5P5F3H7O\$_<TH5.A>_PS[\!Z8.GB_B]9B%G]8]CC.<"ER4``).%A5,!1>_P
M[ZDJA.,*!>R#1P0`I?>1Q(/'!`";AR?]@<=FA`5%6;^#QQ0`X=O5OX5%3H7O
M\`^P<?'.A1<E```3!85.[_`_M$Z%[_"OR4VU[_!/V@-'!0"JAQG+DP;P`H4'
M8Q/7`#Z%`\<'`'7[@H""@%W)01$BX`;D@T<%`"J$V<OO\"^G$P;U_R*6$P?P
M`F-FQ`"MH'T68P7$!H-'!@#CB^?^8WW$!!,'\`)]%F,*Q`2#1P8`XYOG_A,'
M\`(IH(-'!@!CE><`?1;C:\3^`8X3!R8`A6<!16/OYP"%9@4&HH47A0``$P4E
MG._PK]$7A0``$P5EFZ)@`F1!`8*`XQ[$^@-'!`"3!_`"%R4``!,%)4-C%O<`
M%R4``!,%93\"9*)@00%O\`^\%R4``!,%13YO\$^[EV<``).'ASB,:Y!OE'.8
M=X/7!P-9<:;LEX0``(.T!(VB\,KHSN2&](A@*OP!12[H,NPV\#KT(QCQ`F``
M%RD``!,)R3V7B0``@[G)BZ*%2H7O\(_P%<$R1X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_!O[F7Q%RD``!,)"3N7B0``@[D)B**%2H7O\,_L%<$R1X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"OZF7Q%RD``!,)R3>7B0``@[E)
MA**%2H7O\`_I%<$R1X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_#OYF7Q
M%RD``!,)"367B0``@[F)@**%2H7O\$_E%<$R1X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_`OXV7Q%RD``!,)R3&7>0``@[G)?**%2H7O\(_A%<$R1X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_!OWV7Q%RD``!,)"2^7>0``@[D)
M>:*%2H7O\,_=%<$R1X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"OVV7Q
M%RD``!,)R2.7>0``@[E)=:*%2H7O\`_:%<$R1X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_#OUV7Q%RD``!,)B2B7>0``@[F)<:*%2H7O\$_6%<$R1X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_`OU&7Q%RD``!,)R267>0``@[G)
M;:*%2H7O\(_2%<$R1X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_!OT&7Q
M%RD``!,)"2.7>0``@[D):J*%2H7O\,_.%<$R1X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_"OS&7Q%RD``!,)R167>0``@[E)9J*%2H7O\`_+%<$R1X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_#OR&7QHH47)0``$P5E'._P[\>J
MA1G%%R4``!,%91GO\(_VHH47)0``$P4%'._P#\:JA1G%%R4``!,%A1SO\*_T
MHH47)0``$P6E'._P+\2JA0W-%R4``!,%)0SO\,_RER4``).%91X7)0``$P5E
M$>_PC_%B=YQ@N8\!1ZGGIG`&=.9D1FFF:65A@H"BA1<E```3!049[_"/OZJ%
M`<D7)0``$P4%$._P+^Y=ORE&ER4``).%A1@3!1$"[^#?WTWQDP6Q`NF_[_`/
MDWEQ)NR7=```DX0$,R+PB$`7=````S1$5!Q@/N2!1P;T_5=C#/4`(F<<8+F/
M`4>-ZZ)P`G3B9$5A@H!,`!<E```3!84)[_`/N*J'`46!RX/'!P")QY.'!_TS
M-?``B,#AM^_PSXQ!$0;D[^!?VP$E[_#OA1'!"&&B8$$!@H`Y<4KP%WD```,Y
M24TF]$P`JH2#-PD`/N2!1Q<E```3!>4.!OPB^$[L[_`/LA7%@T<%`"J$E<.F
MA>_@G^$IP2)G@S<)`+F/`4>E[^)P0G2B=`)YXFDA88*`(F>#-PD`N8\!1Z:%
ML>]"=.)PHG0">>)I%R4``!,%A0DA86_PC]PFA>_@'].JB2*%[^"?TDZ5"07O
MX!_3(HB7)P``DX>G]2:'A467)@``DX;F]7U6*H3OX#_[(F>#-PD`N8\!1Z*%
MQ=?OX!__)7$BZTKC(607>0``$PG)'N%R)N?._M+Z!N_6]MKRWN[BZN%W%I$#
M-PD#DP0$%:J)$P4$%1,$A!2^E!=Z```#.JH]"I23A<?L`S.)`+.')`"#.`D!
M`SB)`0,V"0*#-HD"`SX*`",PQ`$!3BZ5%RX``!,.CNDCM.?R%R<``!,'1_^S
M!24`([S'[1<E```3!47H([`'[B.XY^XCO`?N([!G\".T%_$CN`?Q([S'\".P
MU_+O\$^=$<6#1P4`*H1CG`<Z[^#?P0$E[^!_[&,,!3``86,)!#`BA>_@?\$&
M!04%[^#_P0-'!`"JB@W#UH07*P``$PL+^2:%VH9]5H5%!03OX/_I`T<$`(D$
M=?=A>R%GDP0+\),'!Q6FEQ,+R^RSA"<`DP<'%=J7%R4``!,%Y>PSBR<`*:"(
M9*$$8P@%#MJ%[_!OE"J$9=F#1P4`[=?O\*^N==$BA>_@G]@JA'G%(H7OX/^X
MJH16A>_@?[BIG)N$1$`FA>_@O[C6B)<G``"3A\?;%R@``!,(2/`BAY<F``"3
MAB;P?5:%1:J*[^!?X),%`!Q6A>_@O]']5V,8]0#OX!^W'$%%1V.?YRAA>Z%G
MDP4+\Y.'!Q6NE[.%)P!6A>_@']0JA$7%EW<``(.W!RB#M@D`B&-6AQ<F```3
M!H;OA47OX/_8@42A9Y.'AQ2*EYAC@S<*`+F/`4=CE`=*H6(6D?I@)H5:9+ID
M&FGV>59ZMGH6>_9K5FP=88*`H6=A>Y.'!Q7:EQ<D```3!"3C@40SBR<`$:B3
MES0`VI<#M`?M#<2#1P0`E<,BA>_P#YZ%)'W1(H7OX-_'*H3C&P7NDY<T`-J7
M`[0'[6G\`435M:%GDX<'%=J7LXLG`(.G"_2]9A%G]8_CDN?T`ZR+]._@7Z2;
M!P4`XQK\\H.G"_03!P`<D_?W'^.2Y_(FA>_@?Z2A9Y,%R^R3AP<5KI>SA2<`
MJH07)0``$P6%YN_@'_NJA6,*!1P#M0D`[_!/V:J+8P,%'%Z%[^#_GQL+!0"-
M1V/89P,3!<O_ER4``).%Q>->E>_@/[()[9%'8P+[,)L'N__>EP/'!P"3!_`"
M8PGW+H,G"0!]5V.'YRICA0<8ER4``).%9=`7)0``$P5EQ>_PCZ/OX#^M*HB7
M*```DXA([9<G``"3A\>]5H>7)@``DX:FWWU6A44FA>_@W\)]6<5)%RP``!,,
MS.J7*P``DXM+NQ<K```3"TO>):#OX+^8'$%CES<#[^`?J`4D*HABX**(WH=6
MA]J&?5:%12:%[^"?OI,%`!PFA>_@_Z_C""7]5H7OX%^LIH47)0``$P7EL^_P
MCYHFA>_P'[81O>%Z(6<3B\KLDP<'%=J7,XLG`),'!Q76EX%$%R4``!,%A<6S
MBB<`.:"3ES0`UI<#M8?N!<7:A>_@W^:%)'75@T<%`/W3[^!_JRJ$XQ0%RI.7
M-`#6EP.UA^YQ_35%[^#_BZJ*%R0``!,$A,$3!S`%:;D7=P```S<G``AC@[8)
M`%:'%R8``!,&IL.%1>_@'[&!1$FS[_"?K*%GDX>'%(J7F&.#-PH`N8\!1V.2
M!R*A8A:1^F"Z9!II]GE6>K9Z%GOV:U9L(H5:9!UA;^`_HX.["0`MO9=W```C
MH`?4@45>A>_@W[0JB^,(!>8)1KE5[^#_F6%TH6D3"83_DX<)%<J7,XDG`!E&
MRH5:A>_@/Z:3APD5HI>*EP/'A_\9YP/'E_^3!C`$8P_7$@%&@45:A>_@_Y7O
M$&!L872A9Q,)A/^3AP<5RI>JB3.))P`IH,J%3H7O$,!O(6;*A5J%[^`_H1L&
M!0#C1<#^6H7OX%^1(6L3"03[DP<+%<J7,XDG`,Z%2H7O$$!Z$P2$_),'"Q6B
MES.$)P`3"X0"ERD``).):;`#1PD`(H7.AGU6A44)!._@'Z$%">,6B_ZA9N%W
M$X<&%1.(A_P^EY.'!A4S`R<`PI<SB"<`ER@``).(*,>7)P``DX>GEU:'ER8`
M`).&AKA]5H5%)H4C"`/^[^!_G/6SX76A9Y.%Q>R3AP<5KI>SA2<`%R4``!,%
M99KOX/_(XPT%ZH-'!0#CB0?J$P<``^.%Y^J%1R,@^0`-LX.YB0#CAPG03H7O
MX,_LC4?C\:?0<167)0``DX6%L4Z5[^!O_^,7!<[.B^6Q`\:G_Y,&$`3C'];J
M@\:W_^.;YNJ#QL?_$P>`!..5YNH#Q]?_DP=0!.,?]^@)1I,%8/Q:A>_@;__*
MA1,&D`):A>_@OXR7*```DXCHN4J(ER<``).'1XI6AY<F``"3AB:K?5:%12:%
M[^!?CRF[[^#_DUUQAN2BX";\2OA2\$[T5NP7=````S2DU0A`%WD```,YB=2#
M-PD`/N2!1^_@'X2JA`A`$PI!`._@7X,#QP0+JH?2A1<E```3!06(HXCG"N_@
M7[@9Q0-'!0"3!Q`#8P?W$N_PK\$(0._@7X"-1@5&ER4``).%1:;OX$_CJH0%
MQ0A`[^"O_IQH%R8``!,&1J6,8^_@K^*<:)QCW$>;UV<!A8MCE`<0"$"7>0``
MDXE)TN_@S_N-1@5&ER4``).%Q:+OX,_>JH0=P=*%%Q4``!,%)7KOX#^PJHH(
M0&.."@KOX._XG&A6AHQC[^!/W0A`[^#O]ZJ$"$#OX&_W!4:7)0``DX4%G^_@
MC]"JA1<F```3!J:?)H7OX(_:"$#OX"_UHP@%"M*%%Q4``!,%A7/OX)^J([BI
M`"J$#<V3!0`<(H7OX._LQ4=C!_4`FP<5``5'8V;W!B)G@S<)`+F/`4>UZZ9@
M!F3B=$)YHGD">N)J86&"@`.UB0#O\,_]([BI`"J$3?T7)0``$P7%F._@3^^#
M1Q4`XXL'[/FU[^!O[0.WB0"<:`QCB&/OX-_#D;<(0._@#^R<:(QC[^"/Z?VU
M@[>)`*J&(H:,8Q<E```3!067[^`/Z^_@S_8Y<2;TEW0``(.TQ+B<8#[D@4<B
M^$[L!OQ*\*J)[_"OG(-'!0`JA)'+$P?P`@4%8Y/G`"J$@T<%`/7[%WD``!,)
M:9.#)PD`?5=CA.<"D<=CA0D`@\<)`+'C(F><8+F/`4>MZ^)P0G2B=`)YXFDA
M88*`3``7%0``$P7E:>_@?Y@IQ8-'!0"QPQ,'``-CC^<"A4<C(/D`XY\)^L&W
M$4:7%0``DX5%=B*%[^`ON%WU(F><8+F/`4>9[T)TXG"B=`)Y3H7B:2%A;^"?
MG9=W```CI`>*8;?OX&_I$P$!TR,T$2PC,($L(SR1*B,X(2LC-#$K(S!!*R,\
M42F7>```@[BHJ3@`_5]!;X.W"``C-/$H@4<3`X4#DP.%!SJ(D]\/`K<"_P`3
M#P_P`S8#`$$((0.3508"DQ:&`1,4A@"35X8"DUZ&`)-4A@,3GH4!L_;V`3-T
M5`"S]^<!P8ZS_NX!Q8\S?OX!H@6SYM8!&U:&`;/GQP&S]54`T8[-CR,XV/XC
M//C^XY-C^GU6$P,'(`&2/'<#.`<$#&L48[/'!P&MC[6/DY87`/V#U8_QCUSC
M(0?C$&?^@SX%`*)B#&D#,X4``SB%`0,^!0(WAX):$P>7F9/7O@$3GUX`,V__
M`+J2DU\C`+/&!0&3%^,!,W_/`/*2L^?W`;/V9@`6G\)BL__'`+/&!@$VG[/&
M]0$S?\\`L_;6`;J2DQ-?`)-4OP&MCL*2EI:SXI,`$]DN`!.4[@&6EN)B,V0D
M`:&/L_?G`;J2\8ZNDK/']P&3E%8`$]FV`9,3[P&6EQ-?+P""<K/CXP$S[R0!
M^I<S3W0`NI)QC#-_WP#QCY:?,T^/`).45P`3V;<!DY+F`7Z?B8*B?[/BT@"S
MYB0!-I^SQE,`,W_/`+/SPP#]CKJ?HI^3%%\`$UF_`;/&=@`3E.<!B8-=C/Z6
ML^<D`;Z6L__&`,)VL\>"`+/WYP&S\L(`NI:>EI.47P`3V;\!L\=7`+:7L^8D
M`;:7DQ/O`1-?+P"SX^,!,__'`.)WLT9T`+/V]@%QC+J7EI>3%%\`$UF_`:&.
MOI:SYR0!OI:3DN\!D]\O`+/B\@&S_\8`AF:SQU,`L_?G`;/SPP"ZEJ*6DY1?
M`!/9OP&SQW<`MI>SYB0!MI<3%.\!$U\O`#-DY`$S_\<`IF>SQH(`L_;V`;/R
MP@"ZEYZ7DQ1?`!-9OP&SQE8`OI:SYR0!OI:3D^\!D]\O`+/C\P&S_\8`QF:S
M1W0`L_?G`7&,NI:6EI.47P`3V;\!H8^VE[/F)`&VEY,2[P$37R\`L^+B`3/_
MQP#F9[/&4P"S]O8!L_/#`+J7HI>3%%\`$UF_`;/&=@"^EK/G)`&^EA.4[P&3
MWR\`,V3T`;/_Q@"&=K/'@@"S]^<!L_+"`+J6GI:3E%\`$]F_`;/'5P"VE[/F
M)`&VEY,3[P$37R\`L^/C`3/_QP"F=[-&=`"S]O8!<8RZEY:7DQ1?`!-9OP&A
MCKZ6L^<D`;Z6DY+O`9/?+P"SXO(!L__&`,9VL\=3`+/WYP&S\\,`NI:BEI.4
M7P`3V;\!L\=W`+:7L^8D`;:7$Q3O`1-?+P`S9.0!,__'`.9WL\:"`+/V]@&S
M\L(`NI>>EY,47P`36;\!L\96`+Z6L^<D`;Z6DY/O`9/?+P"SX_,!L__&`(IF
MLT=T`+/WYP%QC+J6EI:3E%\`$]F_`:&/MI>SYB0!MI>3$N\!$U\O`+/BX@$S
M_\<`JF>SQE,`L_;V`;/SPP"ZEZ*7DU2_`1,47P"SQG8`$YGO`;Z6D]\O`+-G
ME`!*9+-O^0&^EK/'\@'QCK/RP@`ZE+/WYP&BDY/4M@&SQU<`$Y16`$6,GI?J
M9),3[P$37R\`L^/C`:*7\8\SSW\`NI2S_\\`$]FW`3-_WP`3E%<`II(S3_\!
M,V0D`7&,%I^3DN8!B8(BG[/BT@`*>;-TSP"SQE,`_8ZS\\,`$Y14`)/9M`$Z
MF3/'=@"S9C0!$Y3G`8F#78S*G[/'@@#QCGZ7L\?G`2I_LP_7`#?WV6X3!Q>Z
ML_G/`!/9N0$ZGY.660`>G_&/L^8F`?J7\8Z^EI.3Y`'*=XF`L^.3`#/YQ@`S
M3W0`L_+"`)-4N0&ZE[-/_P$3'UD`L__/`):7,V^?`/Z7,W_/`#Z?DY+I`>IW
MD]DI`+/B,@&S=,\`L\]3`'&,D]FT`;J7L\_?`).65`"S_\\`HI>SYC8!_I?Q
MCKZ6DQ_I`8YG$UDI`+/O+P$S],8`,\GR`;/YPP"ZE[-#Z0$36;0!$Q]4`+/S
MPP#.ES-O+P&>ES-_SP`^GY.3Y`&N9XF`L^.3`#/)?P"S=,\`L_G"`+J7LT+9
M`!/9M`&3EE0`L_+"`,Z7L^8F`9:7\8Z^EI,2Y`'.9PF`L^*"`#/)4P`S],8`
ML_G/`+J7LT_I`1-9M`$3'U0`L__/`,Z7,V\O`?Z7,W_/`#Z?DY_D`>YGB8"S
M[Y\`,\GR`;-TSP"S^<,`NI>S0]D`$]FT`9.65`"S\\,`SI>SYB8!GI?QCKZ6
MDQ/D`8YW"8"SXX,`,\E_`#/TQ@"S^<(`NI>S0ND!$UFT`1,?5`"S\L(`SI<S
M;R\!EI<S?\\`/I^3DN0!KG>)@+/BD@`SR5,`LW3/`+/YSP"ZE[-/V0`3V;0!
MDY94`+/_SP#.E[/F)@'^E_&.OI:3'^0!SG<)@+/OCP`SR?(!,_3&`+/YPP"Z
ME[-#Z0$36;0!$Q]4`+/SPP#.ES-O+P&>ES-_SP`^GY.3Y`'N=XF`L^.3`#/)
M?P"S=,\`L_G"`+J7LT+9`!/9M`&3EE0`L_+"`,Z7L^8F`9:7\8Z^EI,2Y`&2
M9PF`L^*"`#/)4P`S],8`L_G/`+J7LT_I`1-9M`$3'U0`L__/`,Z7,V\O`?Z7
M,W_/`#Z?DY_D`;)GB8"S[Y\`,\GR`;-TSP"S^<,`NI>S0]D`$]FT`9.65`"S
M\\,`SI>SYB8!GI?QCKZ6DQ/D`=)G"8"SXX,`,\E_`#/TQ@"S^<(`NI>S0ND!
M$UFT`1,?5`"S\L(`SI<S;R\!EI<S?\\`/I^3DN0!\F>)@+/BD@`SR5,`LW3/
M`+/YSP"ZE[-/V0`3V;0!DY94`+/_SP#.E[/F)@'^E_&.OI:3'^0!DG<)@+/O
MCP`S^<8`,\3R`;/YPP"ZE[-#Y`$35+D!$Q]9`+/SPP#.ES-OCP">ES-_SP`^
MGQ.4Y`&R=XF`18RSPX\`LW3/`+/YP@"ZE[/"TP"3T[0!DY94`+/RP@#.E[/F
M=@"6E_&.OI:3$ND!TG<362D`L^(B`;-#5``S^<8`L_G/`+J7L\_C`9-3N0$3
M'UD`L__/`,Z7,V]_`#-_SP#^E[./YP&3D^0!\G>)@+/CDP`SSW(`L_3/`'&,
MNI<S3]\`,W_/`)/9M`&BEQ.45`#ZES-O-`'ZEY,6Z0$6;Q-9*0"SYB8!,\G3
M`#/TQP"S\L(`LT?Y`3J?\8\35[0!%I\3&50`DY_D`8F`L^^?`#-IZ0`^G[/T
MQ@!*G[/F]@&S\L\`,W_/`#?WQB,S]H8`MF;]5PH'@9,3!\?-,_E4`+J6L_/S
M`+:3DUF_`3-F)@$3&5\`$QKD`9-6)``>EC-D.0$BEC-T]@!69K-FV@"S\_8`
ML^_?`#/Y<@`ZEK/_[P&RE)-9M`&S[R\!$QE4`*:?LV0Y`1,6[P&FGQ-?+P#V
M9#-FY@$S?_8`T8ZS__\`,_GC`>&.NI26E)/9OP&SYB8!$YE?`*:6LV0Y`1,:
MY`&34B0`II:6=+-B6@`S]/(`,V96`/V.,WF/`+J4,W;V`::3,V8F`9.45@`3
MV;8!L^0D`1Z6DYGO`2:6D]\O`+9TL^_Y`;/S_P"SXO(!?8XS>70`L_+2`+J4
ML^(B`?J4$QE6`)-9M@$3G^8!B8(S;]\`LX:2`+-B.0&6EM9RLW3_`+/O[P']
MCC/YDP"ZDK/_SP"S[R\!%I03F58`D]FV`9,2Y@$)@K/BP@`SAH\`LV\Y`7Z6
M]G\S]/(`,V]?`'V.,_F$`+J?,W_?`#-O+P'^DQ,95@"36;8!DY_F`8F"L^_?
M`+,&?P`S;SD!^I8:;[/S_P"SXO(!_8XS>70`.I^S\L(`L^(B`?J4$YE6`)/9
MM@$3'^8!"8(S;\\`,X:2`+-B.0$6EKIBLW3_`+/O[P%]CC/YDP"ZDK/_WP"S
M[R\!%I03&58`DUFV`9.2Y@&)@K/BT@"SAH\`LV\Y`?Z6VF\S]/(`,V]?`/V.
M,_F$`+J?,W_/`#-O+P'^DQ.95@"3V;8!DQ_F`0F"L^_/`#,&?P`S;SD!>I9Z
M;[/S_P"SXO(!?8XS>70`.I^S\M(`L^(B`?J4$QE6`)-9M@$3G^8!B8(S;]\`
MLX:2`+-B.0&6EIIRLW3_`+/O[P']CC/YDP"ZDK/_SP"S[R\!%I03F58`D]FV
M`9,2Y@$)@K/BP@`SAH\`LV\Y`7Z6NG\S]/(`,V]?`'V.,_F$`+J?,W_?`#-O
M+P'^DQ,95@"36;8!DY_F`8F"L^_?`+,&?P`S;SD!^I9:?[/S_P"SXO(!_8XS
M>70`.I^S\L(`L^(B`?J4$YE6`)/9M@$3'^8!"8(S;\\`,X:2`+-D.0$FEOIT
MLW+_`+/O[P%]CC/Y4P"S_]\`NI2S[R\!HI03&58`DUFV`1.4Y@&)@E6,LX:?
M`+-D.0$>:;-_]``S;X\`II8S?\\`L_3R`3J9_8X>F3-OGP"3F58`$]JV`9-3
M)@"3%.8!2I\^:;/D=``SYDD!L_/T`#*?,V:4`'6.,W3_`#J9,_]_`!:9DQE4
M`!-:M`$S9N8!D](F`!.?Y@%*EK/F20$S;U\`-I:SYN0!LW3V`%YFLW+_`#/Y
M4P#ACCJ6?I:SYB8!DY]4`!/9M`&S[R\!LI;^EA,6Y`'^;PF`08XS=/8`,V_/
M`/V.,_J"`#-_GP"ZGY/9M@&>GQ.95@`S;T\!,VDY`7Z?GGF3WR0`DY/D`;/C
M\P&S__,`,WGY`#-F=@!*GW6.LWKT`;J9LW3_`#-G5@$SAED`,I<3F50`$]8F
M`!/:M`&3DN8!L^+"`#-I20&SQE,`,WGY`#J9L\;F`3>WF#(^?PH'$P=G';-Y
M^0"3T[D!.I\3EED`(I_]CC-F=@!]COJ6DY/D`5YTB8`SC\8`L^.3`#/&<@"S
M=/\`.I0S1B8!DY94`!/9M`&BGWV.L^8F`?V.?I8VEA.4Z0'^=I/9*0`S9#0!
M,WGV`+//@P"S\O(`DUFY`;J6L\_O`1,?60"S__\`EI8S;S\!_I8S?_\`-I^3
MG^0!@S8!((F`L^^?`+-"]`&S=/\`L_/S`)/9M`&ZEK/"P@`3EE0`L_+R`)Z6
M,V8V`9:6?8XVEI,3Z0&#-H$@$UDI`+/C(P&SPG\`,WGV`'V,DUFY`;J6L\+B
M`1,?60"S\O(`HI8S;S\!EI8S?_\`-I^3DN0!@S8!(8F`L^*2`#/$4P"S=/\`
ML_G_`+J6LT_$`!/4M`$3EE0`L___`,Z608[^EGV.-I:3'^D!@S:!(1-9*0"S
M[R\!,W3V`#/)\@&S^?,`NI:S0^D!$UFT`1,?5`"S\_,`SI8S;R\!GI8S?_\`
M-I^3D^0!@S8!(HF`L^.3`#/)?P"S=/\`L_GR`+J6LT+)`!/9M`$3EE0`L_+R
M`,Z6,V8F`9:6?8XVEI,2Y`&#-H$B"8"SXH(`,\E3`#-T]@"S^?\`NI:S3^D!
M$UFT`1,?5`"S__\`SI8S;R\!_I8S?_\`-I^3G^0!@S8!(XF`L^^?`#/)\@&S
M=/\`L_GS`+J6LT/)`!/9M`$3EE0`L_/S`,Z6,V8F`9Z6?8XVEI,3Y`&#-H$C
M"8"SXX,`,\E_`#-T]@"S^?(`NI:S0ND!$UFT`1,?5`"S\O(`SI8S;R\!EI8S
M?_\`-I^3DN0!@S8!)(F`L^*2`#/)4P"S=/\`L_G_`+J6LT_)`!/9M`$3EE0`
ML___`,Z6,V8F`?Z6?8XVEI,?Y`&#-H$D"8"S[X\`,\GR`3-T]@"S^?,`NI:S
M0^D!$UFT`1,?5`"S\_,`SI8S;R\!GI8S?_\`-I^3D^0!@S8!)8F`L^.3`#/)
M?P"S=/\`L_GR`+J6LT+)`!/9M`$3EE0`L_+R`,Z6,V8F`9:6?8XVEI,2Y`&#
M-H$E"8"SXH(`,\E3`#-T]@"S^?\`NI:S3^D!$UFT`1,?5`"S__\`SI8S;R\!
M_I8S?_\`-I^3G^0!@S8!)HF`L^^?`#-Y_P"SQ/(!L_GS`+J6L\/$`)-4N0$3
M%ED`L_/S`,Z618Z>EGV.-I:3%.0!@S:!)@F`P8RSPY\`,W3V`+/Y\@"ZEK/"
MXP&34[0!$Q]4`+/R\@#.EC-O?P`S?_\`EI:S@N8!DQ/I`8,V`2<362D`L^,C
M`3//=``S^?(`L___`#-/SP"36;D!NI83%ED`_I8S9C8!LW__`'V._I:SC\8`
M$Q_D`0,V@2<)@#-OCP"SQN,!,_3_`/V,.I:SQE8`_8XFEI-9M`&3%%0`-I:S
MYC0!-I:#-@$HDQ+I`1-9*0"SXB(!NI:S1%\`,W?V`/:6L_/S`#/&]`%]CI,>
M5P"37[<!GI:REC/F_@&3'N0!"8"REK/NC@#]CCJ3,P;/`3.'O@"SA0(!?8\4
MX?V-LW;S`/&/&.D<\13E#.T#-X$H@[<(`+F/`4>5XX,P@2P#-`$L@S2!*P,Y
M`2N#.8$J`SH!*H,Z@2D3`0$M@H#OT(_!01$3!0`(!N3OT,^1MW9=3(8&DX;F
MSS=WZ6$W)D5G%.D3!A8PMU8R$`8'$.&3AF9'%T8```,V1BX3!P<?$.44[1CQ
M(S0%`B,X!0(C+`4&HF!!`8*`.7$B^";T2O!2Z`;\3NQ6Y!AUDQ<V`!1YNI>"
M%X&3,[?G`*J$NI8H71-7U@$VEYSTF/@RB2Z$$XJ$`S'MDP?P`V/:)PD;"0G\
MFUII`)N)&@":":*9HH43!@`$4H7OT$^8$P0$!":%[^"?S.,5-/^;FFH`.PE9
M04J&SH52A>_03Y8CK"0'XG!"=*)T`GGB:4)JHFHA88*`DPD`!+N'J4"^B6-(
M]@*;B@D`5H:BA5*5[]`OD[Q<$P<`!+N&^0"TW..3YOPFA3L).4%6E._@7\:]
MM[*)R;^BB46W.7$B^";T2O!.[%K@!OQ2Z%;D`[J%`H/7A0(#UP4#$U8Z`!-V
M]@,;F(<`FQ:'`!.+A0.A@R&#+H2SYP<!LP7+`%6/$P@`^),&%@"#.@0#$YD'
M`R.`!0&3&0<#DP6``ZJ$$UD)`Y/9"0,%)C,%VP!CT-40DP<`!#N&QT"!1>_0
MSYTBA>_@7[T3!H`#@45:A>_0KYR35XH!$]>*`1-:"@&3V@H!(H6C"%0'(QDT
M!R,*]`:C"D0'(QLD!R,(Y`;OX+^Y'&`BA>&#(X#T`!Q@P8.C@/0`'&"A@R.!
M]``<8*.!]``<9.&#(X+T`!QDP8.C@O0`'&2A@R.#]``<9*.#]``<:.&#(X3T
M`!QHP8.CA/0`'&BA@R.%]``<:*.%]``<;.&#(X;T`!QLP8.CAO0`'&RA@R.'
M]``<;*.']``<<.&#(XCT`!QPP8.CB/0`''"A@R.)]``<<*.)]`!"=.)PHG0"
M>>)I0FJB:@)K(6%OT.^!DP>``SN&QT"!1>_0#XX9OY=6``"#MJ8V;\`_\@``
M``````$``@``````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5```
M``!E>&4``````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0````
M``````!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``
M4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)
M3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`
M````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/
M0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?
M5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`
M`````````%!!4E]#3$5!3CT````````Q`````````$Q$7TQ)0E)!4EE?4$%4
M2`!54T52`````%-94U1%30``+W1M<`````!54T523D%-10``````````)3`R
M>`````!P87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``````
M`%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S
M=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````&`````````!P
M97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-30`
M``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``````````+64````````M+0```````%1-4$1)
M4@``5$5-4$1)4@!414U0`````%1-4```````979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-
M04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE
M0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA
M;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC
M;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B
M)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO
M=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y
M<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E
M=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["DU!
M1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@
M*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG
M="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@
M)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US(%]&2#L*;7D@)&UA9VEC7W!O<R`]("1S:7IE("T@)'-I>F4@)2`D
M8VAU;FM?<VEZ93L@(R!.3U1%.B`D;6%G:6-?<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K
M(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D[
M"FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0II9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L
M("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B
M3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*=6YL97-S("@D8G5F(&5Q(")02UPP,#-<,#`T
M(BD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@
M;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#
M86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F
M:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!A<B)=.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M
M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68[
M"G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A
M<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P
M:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D
M92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@
M)&1A=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@
M96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D
M96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]
M?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y
M*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A
M;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N
M("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD
M9F@M/G!R:6YT*"1L;V%D97(I.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@
M<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@
M("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL
M92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K
M97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];
M7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64[
M"FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I
M;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F
M:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\
M)&9H/CL*8VQO<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C
M:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q
M6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE
M>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H
M("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'
M24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE
M*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z
M.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@
M)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT
M<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC
M871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF
M("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613
M:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC
M92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E
M('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S
M=%]N86UE(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI
M8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@
M<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF
M="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H
M+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G
M7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*
M<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@
M<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I
M<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E
M<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q
M=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O
M;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ
M<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA
M;64B.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H
M+"`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<[
M"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E
M('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\
M.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N
M86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C
M='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES
M>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@
M>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L
M:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@
M<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C
M;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*
M?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!
M4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,
M14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L
M96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L
M=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```
M````````B:O-[P`````!&P,[%`````$```#8DO__+``````````0````````
M``-Z4@`!?`$!&PT"`!`````8````I)+__R(`````!P$`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````0````````#O`@``
M``````$`````````_P(````````!``````````D#````````(```````````
MD````````"$`````````"``````````9``````````B0````````&P``````
M```(`````````!H`````````$)`````````<``````````@`````````]?[_
M;P````#8`@````````4`````````.`T````````&`````````,`#````````
M"@````````"K!`````````L`````````&``````````5````````````````
M`````P````````!(H`````````(`````````6`4````````4``````````<`
M````````%P`````````@%0````````<`````````$!,````````(````````
M`&@'````````"0`````````8`````````!X`````````"`````````#[__]O
M``````$```@`````_O__;P````"P$@```````/___V\``````@````````#P
M__]O`````.01````````^?__;P`````+````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````_____P``````````````````````````````
M`````````````````````````````````````````````````/__________
M``````````"`&@```````(`:````````@!H```````"`&@```````(`:````
M````@!H```````"`&@```````(`:````````@!H```````"`&@```````(`:
M````````@!H```````"`&@```````(`:````````@!H```````"`&@``````
M`(`:````````@!H```````"`&@```````(`:````````@!H```````"`&@``
M`````(`:````````@!H```````"`&@```````(`:````````@!H```````"`
M&@```````(`:````````@!H```````"`&@```````(`:````````@!H`````
M``"`&@```````(`:````````@!H```````"`&@```````(`:````````@!H`
M``````"`&@```````(`:````````@!H```````"`&@```````(`:````````
M@!H```````"`&@```````(`:````````@!H```````"`&@```````(`:````
M````@!H```````"`&@```````(`:````````@!H```````"`&@```````(`:
M````````@!H````````8D```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=#0SH@*%5B=6YT=2`Q,2XR
M+C`M,39U8G5N='4Q*2`Q,2XR+C``03(```!R:7-C=@`!*`````5R=C8T:3)P
M,%]M,G`P7V$R<#!?9C)P,%]D,G`P7V,R<#```"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96QA+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N<')E:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N9FEN:5]A
M<G)A>0`N9'EN86UI8P`N9&%T80`N9V]T`"YB<W,`+F-O;6UE;G0`+G)I<V-V
M+F%T=')I8G5T97,`````````````````````````````````````````````
M``````````````````````````````````````````L````!`````@``````
M``!P`@```````'`"````````(0````````````````````$`````````````
M```````3````!P````(`````````E`(```````"4`@```````"0`````````
M```````````$````````````````````)@````<````"`````````+@"````
M````N`(````````@````````````````````!````````````````````#0`
M``#V__]O`@````````#8`@```````-@"````````Z``````````%````````
M``@````````````````````^````"P````(`````````P`,```````#``P``
M`````'@)````````!@````(````(`````````!@`````````1@````,````"
M`````````#@-````````.`T```````"K!````````````````````0``````
M`````````````$X```#___]O`@````````#D$0```````.01````````R@``
M```````%``````````(``````````@````````!;````_O__;P(`````````
ML!(```````"P$@```````&``````````!@````(````(````````````````
M````:@````0````"`````````!`3````````$!,````````0`@````````4`
M````````"``````````8`````````'0````$````0@`````````@%0``````
M`"`5````````6`4````````%````%0````@`````````&`````````!Y````
M`0````8`````````@!H```````"`&@```````+`#```````````````````0
M`````````!``````````?@````$````&`````````#`>````````,!X`````
M``!R+@``````````````````!````````````````````(0````!`````@``
M``````"H3````````*A,````````8$````````````````````@`````````
M``````````",`````0````(`````````"(T````````(C0```````!0`````
M```````````````$````````````````````F@````$````"`````````""-
M````````((T````````L````````````````````"```````````````````
M`*0````0`````P``````````D`````````"0````````"```````````````
M``````$`````````"`````````"S````#@````,`````````")`````````(
MD`````````@````````````````````(``````````@`````````OP````\`
M```#`````````!"0````````$)`````````(````````````````````"```
M```````(`````````,L````&`````P`````````8D````````!B0````````
M$`(````````&``````````@`````````$`````````#4`````0````,`````
M`````*``````````H````````$@````````````````````(````````````
M````````V@````$````#`````````$B@````````2*````````!``@``````
M````````````"``````````(`````````-\````(`````P````````"(H@``
M`````(BB````````*!````````````````````@```````````````````#D
M`````0```#````````````````````"(H@```````"8`````````````````
M```!``````````$`````````[0````,``'``````````````````````KJ(`
M```````S`````````````````````0````````````````````$````#````
M`````````````````````.&B````````_P````````````````````$`````
+````````````````
